unit dlg_WinHelp;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls;

type
  TdlgWinHelp = class(TForm)
    OKBtn: TButton;
    CancelBtn: TButton;
    Bevel1: TBevel;
    e_CompName: TEdit;
    Label1: TLabel;
    e_TopicTitle: TEdit;
    Label2: TLabel;
    Label3: TLabel;
    e_TopicID: TEdit;
    Label4: TLabel;
    cb_TopicType: TComboBox;
    Label6: TLabel;
    e_KeyWords: TEdit;
    e_AWords: TEdit;
    Label7: TLabel;
    BitBtn1: TBitBtn;
    lbl_Font: TLabel;
    Label8: TLabel;
    cbx_Methods: TCheckBox;
    cbx_Properties: TCheckBox;
    cbx_Events: TCheckBox;
    cbx_Component: TCheckBox;
    BitBtn2: TBitBtn;
    lbl_SubFont: TLabel;
    Label5: TLabel;
    cbx_KeyNote: TCheckBox;
    cbx_ANote: TCheckBox;
    procedure cbx_KeyNoteClick(Sender: TObject);
    procedure cbx_ANoteClick(Sender: TObject);
    procedure cb_TopicTypeChange(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure BitBtn1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    procedure SetFontInfo(Title : Boolean);
  public
    { Public declarations }
    TitleFont, SubTitleFont : TFont;
  end;

var
  dlgWinHelp: TdlgWinHelp;

implementation
uses Dialogs, frm_Hoved;

{$R *.dfm}

procedure TdlgWinHelp.SetFontInfo(Title : Boolean);
var
  F : TFont;
  Lbl : TLabel;
begin
      if Title then
      begin
       F := TitleFont;
       Lbl := lbl_Font;
      end
      else
      begin
       F := SubTitleFont;
       Lbl := lbl_SubFont;
      end;

      with F do
      begin
          lbl.Caption := F.Name + ' ' +
          IntTostr(F.Size) + ' ' + ColorToString(F.Color);
          if fsBold in F.Style then
            lbl.Caption := lbl.Caption + ' Bold';
          if fsItalic in F.Style then
            lbl.Caption := lbl.Caption + ' Italic';
      end;
      lbl.Font.Assign(F);
end;

procedure TdlgWinHelp.cbx_KeyNoteClick(Sender: TObject);

begin
    if cbx_KeyNote.Checked then
    begin
          if cb_TopicType.ItemIndex in [1..4] then
           e_KeyWords.Text := e_CompName.Text + ',' + e_TopicTitle.Text + ';' +
           e_TopicTitle.Text + ',' + e_CompName.Text + ';' + e_TopicTitle.Text + ','
          else
           e_KeyWords.Text := e_TopicTitle.Text;
    end
    else
    begin
       e_KeyWords.Text := '';
    end;
end;

procedure TdlgWinHelp.cbx_ANoteClick(Sender: TObject);
var
  S : string;
begin
    if not (cb_TopicType.ItemIndex in [0..5]) and cbx_ANote.Checked then
    begin
       if (Sender <> nil) then
         Showmessage('Not relevant for this topic type')
       else
         e_AWords.Text := '';
       cbx_ANote.Checked := False;
       Exit;
    end;
    if cbx_ANote.Checked then
    begin
          if cb_TopicType.ItemIndex in [2,3] then
            S := 'Method'
          else
            S := cb_TopicType.Text;
          if cb_TopicType.ItemIndex = 0 then
           e_AWords.Text := e_CompName.Text + '_' + S + ';' +
           e_CompName.Text
          else
           e_AWords.Text := e_CompName.Text + '_' + S + ';' +
           e_TopicTitle.Text + '_' + S + ';' + e_TopicTitle.Text;
    end
    else
    begin
       e_AWords.Text := '';
    end;

end;

procedure TdlgWinHelp.cb_TopicTypeChange(Sender: TObject);
begin
  cbx_ANoteClick(nil);
  cbx_KeyNoteClick(nil);
  if Sender = cb_TopicType then
  begin
     if cb_TopicType.ItemIndex in [1..6] then
     begin
          cbx_Properties.Enabled := False;
          cbx_Properties.Checked := False;
          cbx_Methods.Enabled := False;
          cbx_Methods.Checked := False;
          cbx_Events.Enabled := False;
          cbx_Events.Checked := False;
          cbx_Component.Enabled := True;
     end
     else if cb_TopicType.ItemIndex in [0] then
     begin
          cbx_Properties.Enabled := True;
          cbx_Methods.Enabled := True;
          cbx_Events.Enabled := True;
          cbx_Component.Checked := False;
          cbx_Component.Enabled := False;
     end;
  end;
end;

procedure TdlgWinHelp.FormCloseQuery(Sender: TObject;
  var CanClose: Boolean);
begin
    if ModalResult = mrOk then
    begin
       if Trim(e_CompName.Text) = '' then
       begin
         ShowMessage('Missing Component/Object name');
         Canclose := False;
         Exit;
       end;
       if Trim(e_TopicID.Text) = '' then
       begin
         ShowMessage('Missing Topic ID');
         Canclose := False;
         Exit;
       end;
       if (cbx_ANote.Checked) and (Trim(e_AWords.Text) = '') then
       begin
         ShowMessage('Missing A-Words');
         Canclose := False;
         Exit;
       end;
       if (cbx_KeyNote.Checked) and (Trim(e_KeyWords.Text) = '') then
       begin
         ShowMessage('Missing Keywords');
         Canclose := False;
         Exit;
       end;
       if (cb_TopicType.ItemIndex in [0..4]) and
       (Trim(e_TopicTitle.Text) = '') then
       begin
         ShowMessage('Topic type requires a title');
         Canclose := False;
       end;

    end;
end;

procedure TdlgWinHelp.BitBtn1Click(Sender: TObject);
begin
      if frmHoved.FontDialog1.Execute then
      begin
           if Sender = BitBtn1 then
           begin
             TitleFont.Assign(frmHoved.FontDialog1.Font);
             SetFontInfo(True);
           end
           else
           begin
             SubTitleFont.Assign(frmHoved.FontDialog1.Font);
             SetFontInfo(False);
           end
      end;

end;

procedure TdlgWinHelp.FormCreate(Sender: TObject);
begin
  TitleFont := TFont.Create;
  TitleFont.Assign(frmHoved.ws.Font);
  TitleFont.Name := 'Arial';
  TitleFont.Style := [fsBold];
  TitleFont.Size := 14;
  SetFontInfo(True);
  SubTitleFont := TFont.Create;
  SubTitleFont.Assign(frmHoved.ws.Font);
  SubTitleFont.Name := 'Arial';
  SubTitleFont.Style := [];
  SubTitleFont.Size := 8;
  SetFontInfo(False);
  e_CompName.Text := 'TWordSource';
end;

end.
